@@ -142,7 +142,6 @@ def map_queries(
     min_score=40,
     strata=-1,
     accurate_mapq=False,
-    use_alignment_score=False,
     skip_alignment=False,
     max_hits=100,
     semiglobal_alignment=False,
@@ -178,7 +177,7 @@ def map_queries(
             semiglobal_alignment=semiglobal_alignment, threads=threads,
             buffersize=postprocessing_buffersize, paired=paired,
             insert_size=insert_size, insert_size_error=insert_size_error,
-            accurate_mapq=accurate_mapq, use_alignment_score=use_alignment_score,
+            accurate_mapq=accurate_mapq,
             skip_alignment=skip_alignment)
 
         writing_future = pool.submit(
@@ -329,7 +328,6 @@ def _postprocess_hits(
     insert_size=220,
     insert_size_error=50,
     accurate_mapq=False,
-    use_alignment_score=False,
     skip_alignment=False):
     """Worker for postprocessing."""
 
@@ -354,7 +352,6 @@ def _postprocess_hits(
             paired=paired, insert_size=insert_size,
             insert_size_error=insert_size_error,
             accurate_mapq=accurate_mapq,
-            use_alignment_score=use_alignment_score,
             skip_alignment=skip_alignment):
             bam_queue.put((queries, postprocessed_hits))
             logging.debug("bam queue: {} items".format(bam_queue.qsize()))
@@ -441,7 +438,6 @@ def argument_parser():
     group.add_argument("--strata", "-s", default=1, metavar="N", help="How many strata (hits of the same quality) should be reported for each read (default: 1). Use --strata all to report all strata.")
     group.add_argument("--max-hits", "-m", type=int, default=100, metavar="N", help="Maximum number of hits per read (default 100). Regardless of strata value, this limits the number of records per read in the bam file.")
     group.add_argument("--accurate-mapq", action="store_true", help="Do not set all mapping qualities to zero if a read aligns ambiguously to multiple positions. The default behaviour ensures compatibility to downstream tools like GATK.")
-    group.add_argument("--use-alignment-score", "--as", action="store_true", help="Use the aligment score with affine gap costs for sorting hits into strata (see above). This will be slightly more compute intensive as more alignments will have to be calculated.")
     group.add_argument("--insert-size", "--isize", type=int, default=220, metavar="I", help="Expected insert size for read and mate (default 220). See --insert-size-error for effects.")
     group.add_argument("--insert-size-error", "--ierr", type=int, default=50, metavar="E", help="Maximum deviation from expected insert size (default 50). Insert sizes within [I-Em, I+E] will lead to read and mate being marked as properly paired.")
     group.add_argument("--gap-open-penalty", "-O", default=2, type=int, metavar="N", help="Gap open penalty (default 2).")
@@ -517,7 +513,6 @@ def main(profile=False):
                 min_score=args.percent_identity,
                 strata=strata,
                 accurate_mapq=args.accurate_mapq,
-                use_alignment_score=args.use_alignment_score,
                 skip_alignment=args.no_alignments,
                 max_hits=args.max_hits,
                 semiglobal_alignment=args.semiglobal,
